@@ -21,13 +21,8 @@ class S3Base:
             cls.s3_base_logger = logging.getLogger(__name__)
         return cls.s3_base_logger
 
-    def __init__(self,
-                 access_key: str,
-                 access_secret: str,
-                 region: str):
-        self._resource = boto3.Session(aws_access_key_id=access_key,
-                                       aws_secret_access_key=access_secret,
-                                       region_name=region)
+    def __init__(self):
+        self._resource = boto3.Session()
 
     @property
     def resource(self):
