@@ -52,3 +52,12 @@ def is_this_time_behind(base_time: float):
 def is_this_time_ahead(base_time: float):
     # If check time is not given, default to current UTC time
     return pendulum.from_timestamp(base_time) > pendulum.now().in_timezone('UTC')
+
+
+def countdown(base_date: float):
+    return pendulum.now().diff(pendulum.from_timestamp(base_date)).in_seconds()
+
+
+def countdown_for_humanoids(base_date: float):
+    secs = pendulum.now().diff(pendulum.from_timestamp(base_date)).in_seconds()
+    return pendulum.now().add(seconds=secs).diff_for_humans()
